from setuptools import setup


setup(
    name='github_webhook_app',

    version='1',

    description='Quickly create github webhook apps',
    long_description='',

    author='Josh Ghiloni',
    author_email='ghiloni@gmail.com',

    license='MIT',

    packages=['github_webhook_app'],
    zip_safe=False,
)